;+
; skylab_fcorona.pro
; ----------------------------------------------------------------------
; Determines F-corona for radius r (Rsun units)
; ----------------------------------------------------------------------
; SYNTAX:
;	fc = skylab_fcorona (radius, position_angle)
;
;	radius:		radial distance from sun center [Rsun units].
;	position_angle:	angle CCW from solar north [degrees].
;
; HISTORY:
;	Andrew L. Stanger   NCAR/HAO   SMM C/P
;	15 May 1986: F-corona equation taken from Skylab Apollo Telescope Mount ATM/WLCE Technical Memo #15.
;	17 June 1998: Conversion from C to IDL.
; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
;-

FUNCTION skylab_fcorona, radius, theta

;---radius:			/* Radius (R/Rsun). */
;---theta:			/* Position Angle (degrees). */

Cexp   = 1.0e-11;		/* Scale factor for calibrated images. */
raddeg = 0.017453293;		/* Conversion factor: radians / degree. */

;* ---------------------------------------------------------------------- */

  s = sin ( theta * raddeg )
  f = Cexp * 4739.6 * (1.0 + 0.23732 * s*s) * radius ^ (-2.72375)

  IF (f LT 0.0 OR f GT 1.0)  THEN f = -1.0

   RETURN, f
END
